@@ -373,8 +373,7 @@ def write_delta_stream_with_custom_fnc_same_foreach_batch(spark_job_conf: dict,
 ########
 def get_register_avro_schema(kafka_deserialization_conf: dict) -> str:
     kafka_schema_registry_conf = {
-        'url': kafka_deserialization_conf['kafka_schema_registry_url'],
-        'basic.auth.user.info': kafka_deserialization_conf['kafka_schema_registry_basic.auth.user.info']
+        'url': kafka_deserialization_conf['kafka_schema_registry_url']
     }
 
     kafka_schema_registry_subject = kafka_deserialization_conf['kafka_schema_registry_subject_name']
@@ -389,9 +388,7 @@ def get_register_avro_schema(kafka_deserialization_conf: dict) -> str:
 
 def deserialize_register_avro_stream(stream: DataFrame, kafka_deserialization_conf: dict) -> DataFrame:
     from_avro_abris_settings = from_avro_abris_config({
-        'schema.registry.url': kafka_deserialization_conf['schema.registry.url'],
-        "basic.auth.credentials.source": kafka_deserialization_conf['basic.auth.credentials.source'],
-        'basic.auth.user.info': kafka_deserialization_conf['basic.auth.user.info']
+        'schema.registry.url': kafka_deserialization_conf['schema.registry.url']
     }, kafka_deserialization_conf['topic'], False)
 
     deserialized_stream = stream \
@@ -403,9 +400,7 @@ def deserialize_register_avro_stream(stream: DataFrame, kafka_deserialization_co
 
 def serialize_register_avro_stream(stream: DataFrame, kafka_serialization_conf: dict) -> DataFrame:
     to_avro_abris_settings = to_avro_abris_config({
-        'schema.registry.url': kafka_serialization_conf['schema.registry.url'],
-        "basic.auth.credentials.source": kafka_serialization_conf['basic.auth.credentials.source'],
-        'basic.auth.user.info': kafka_serialization_conf['basic.auth.user.info']
+        'schema.registry.url': kafka_serialization_conf['schema.registry.url']
     }, kafka_serialization_conf['topic'], False)
 
     serialized_stream = stream \
